import { config } from '../config.js';
import { Client as DeviceClient } from './device/client.js';
import { Client as ForwardingClient } from './forwarding/client.js';
export const device = new DeviceClient(config.BASE_URL, {
    serviceUrl: config.DEVICE_SERVICE_URL,
    fixedHeaders: [['x-request-authentication', 'experiment-service']],
});
export const forwarding = new ForwardingClient(config.BASE_URL, {
    serviceUrl: config.FORWARDING_SERVICE_URL,
    fixedHeaders: [['x-request-authentication', 'experiment-service']],
});
export const clients = { device, forwarding };
export const middleware = (req, _res, next) => {
    const forward_headers = ['x-request-authentication'];
    const fixed_headers = forward_headers
        .map(forward_header => {
        const value = req.header(forward_header);
        if (value)
            return [forward_header, value];
        else
            return undefined;
    })
        .filter(fixed_header => !!fixed_header);
    const bound_device = new DeviceClient(config.BASE_URL, {
        serviceUrl: config.DEVICE_SERVICE_URL,
        fixedHeaders: fixed_headers,
    });
    const bound_forwarding = new ForwardingClient(config.BASE_URL, {
        serviceUrl: config.FORWARDING_SERVICE_URL,
        fixedHeaders: fixed_headers,
    });
    req.clients = { device: bound_device, forwarding: bound_forwarding };
    next();
};
//# sourceMappingURL=index.js.map